/* The global array that contains all modified text field ids. */
var dpgem_editedFields;

/* The global array that contains all TinyMCE instance ids that where visible
   curing the current session. If not inside this array, the instance is hidden
   by default. */
var dpgem_visibleTinyMCEInstances;

/**
 * public function js_dpgfrontend_editmode_notify_change()
 *
 * This public procedure inserts the >id< into the global array
 * "dpgem_editedFields" which determines the text fields whose
 * content has probably been modified.
 *
 * @access public
 * @param id: string
 * @return void
 **/
function js_dpgfrontend_editmode_notify_change(id) {
    if (jQuery.inArray(id, dpgem_editedFields) < 0)
        dpgem_editedFields.push(id);
}

/**
 * public function js_dpgfrontend_editmode_undo_change()
 *
 * This public procedure removes the >id< from the global array
 * "dpgem_editedFields" which determines the text fields whose
 * content has probably been modified.
 *
 * @access public
 * @param id: string
 * @return void
 **/
function js_dpgfrontend_editmode_undo_change(id) {
    dpgem_editedFields = jQuery.grep(dpgem_editedFields, function(value) {
        return value != id;
    });
}

$(document).ready(function() {
    var dpgem_editMode_Active;
    var dpgem_pathTo_Root;

    // init edit mode
    dpgem_init(true);

    /* -------------------------------------------------------------------------
     *
     *  initial procedures
     *
     * -------------------------------------------------------------------------
     */

     /**
     * dpgem_layers(edit_mode: boolean)
     *
     * @access private
     * @return void
     **/
     function dpgem_layers(edit_mode, doNotHideToolbar) {
        return (
            '<div id="dpgem-toolbar" style="' + (!doNotHideToolbar? 'display: none;': 'display: block;') + '" class="dpgem-toolbar">' +
                '<div class="dpgem-logo"></div>' +
                '<div class="dpgem-newsticker"><iframe frameborder="0" height="20" id="dpgem-ticker-iframe" name="dpgem_ticker" scrolling="no" src="http://www.dynpg.org/em_ticker_' + dpgem_languageDef['LANG_EM_LANGUAGE'] + '.php" ALLOWTRANSPARENCY="true"></iframe></div>' +
                '<div id="dpgem-button-logout" title="' + dpgem_languageDef['LANG_EM_LOGOUT'] + '" class="dpgem-button"><div class="dpgem-button-text"><strong>X</strong></div><span></span></div>' +
                '<div id="dpgem-button-refresh" class="dpgem-button"><div class="dpgem-button-text"><img src="' + dpgem_pathTo_Root + 'pictures/frontend_em_refresh.png" title="' + dpgem_languageDef['LANG_EM_REFRESH'] + '" alt="' + dpgem_languageDef['LANG_EM_REFRESH'] + '" class="dpgem-button-image-single" /></div><span></span></div>' +
                '<div id="dpgem-button-save" class="dpgem-button"><div class="dpgem-button-text"><img src="' + dpgem_pathTo_Root + 'pictures/frontend_em_save.png" title="' + dpgem_languageDef['LANG_EM_SAVE'] + '" alt="' + dpgem_languageDef['LANG_EM_SAVE'] + '" class="dpgem-button-image-single" /></div><span></span></div>' +
                (edit_mode?
                '<div id="dpgem-button-accept" class="dpgem-button"><div class="dpgem-button-text"><img src="' + dpgem_pathTo_Root + 'pictures/frontend_em_accept.png" title="' + dpgem_languageDef['LANG_EM_LIVE'] + '" alt="' + dpgem_languageDef['LANG_EM_LIVE'] + '" class="dpgem-button-image-single" /></div><span></span></div>':
                '<div id="dpgem-button-accept" style="display: none;" class="dpgem-button button-hidden"><div class="dpgem-button-text"><img src="' + dpgem_pathTo_Root + 'pictures/frontend_em_accept.png" title="' + dpgem_languageDef['LANG_EM_LIVE'] + '" alt="' + dpgem_languageDef['LANG_EM_LIVE'] + '" class="dpgem-button-image-single" /></div><span></span></div>') +
                (!edit_mode?
                '<div id="dpgem-button-edit" class="dpgem-button"><div class="dpgem-button-text"><img src="' + dpgem_pathTo_Root + 'pictures/frontend_em_edit.png" title="' + dpgem_languageDef['LANG_EM_EDIT'] + '" alt="' + dpgem_languageDef['LANG_EM_EDIT'] + '" class="dpgem-button-image-single" /></div><span></span></div>':
                '<div id="dpgem-button-edit" style="display: none;" class="dpgem-button button-hidden"><div class="dpgem-button-text"><img src="' + dpgem_pathTo_Root + 'pictures/frontend_em_edit.png" title="' + dpgem_languageDef['LANG_EM_EDIT'] + '" alt="' + dpgem_languageDef['LANG_EM_EDIT'] + '" class="dpgem-button-image-single" /></div><span></span></div>') +
                '<div class="dpgem-button-shrink"><img src="' + dpgem_pathTo_Root + 'pictures/frontend_em_toolbar_shrink.png" alt="shrink" id="dpgem-button-shrink" /></div>' +
                '<div class="dpgem-button-blow"><img src="' + dpgem_pathTo_Root + 'pictures/frontend_em_toolbar_blow.png" alt="blow" id="dpgem-button-blow" /></div>' +
            '</div>' +
            '<div id="loadingBar" style="display: none;" class="dpgem-loadingbar"><img src="' + dpgem_pathTo_Root + 'pictures/loading_bar.gif" alt="loading..." /></div>' +
            '<div id="dynamic-container" style="display: none; filter:alpha(opacity=10); -moz-opacity: 0.7; opacity: 0.7; width: 100%; position: absolute; top: 0; left: 0; z-index: 800; background-color: white;"></div>'
        );
     }

    /**
     * dpgem_init(edit_mode: boolean)
     *
     * @access private
     * @return void
     **/
    function dpgem_init(edit_mode, doNotInitialize) {
        dpgem_editMode_Active = edit_mode;
        x_dpgem_path_to_root(function(z) { dpgem_pathTo_Root = z; });

        // If doNotInitialize, then append layers and create array of edited
        // fields dpgem_editedFields since this is the initial call of
        // this method (first load of document).
        if (!doNotInitialize) {
            // add edit toolbar to current document DOM
            $('body').append(dpgem_layers(true));
            dpgem_editedFields = new Array();
        }

        // read all visible TinyMCE instances
        dpgem_visibleTinyMCEInstances = new Array();
        x_dpgem_get_visible_tinyMCE(null, false, function(z){
            dpgem_visibleTinyMCEInstances = z;
        });

        // re-append layer
        jv_dpgfrontend_editmode_append_layers();


        // [[ begin : "handle toolbar"
        // ---
        // bind active/inactive effects to toolbar buttons
        $('.dpgem-button').each(
            function(i) {
                $(this).bind({
                  mouseleave: function() {
                    $(this).toggleClass('dpgem-button-active');
                    $(this).children('div').each(
                        function() {
                            $(this).toggleClass('dpgem-button-text-active');
                        }
                    );
                    $(this).children('span').each(
                        function() {
                            $(this).toggleClass('dpgem-button-span-active');
                        }
                    );
                  },
                  mouseenter: function() {
                    $(this).toggleClass('dpgem-button-active');
                    $(this).children('div').each(
                        function() {
                            $(this).toggleClass('dpgem-button-text-active');
                        }
                    );
                    $(this).children('span').each(
                        function() {
                            $(this).toggleClass('dpgem-button-span-active');
                        }
                    );
                  }
                });
            }
        );

        // fade toolbar to visible
        if (!doNotInitialize) {
            $('#dpgem-toolbar').fadeTo('slow', 0.9);
        }

        // bind click events to toolbar buttons
        $('#dpgem-button-save').bind('click', function() { jv_dpgfrontend_editmode_save(); });
        $('#dpgem-button-refresh').bind('click', function() {
            jv_dpgfrontend_editmode_save();
            jv_dpgfrontend_editmode_reload();
        });
        $('#dpgem-button-accept').bind('click', function() { jv_dpgfrontend_editmode_toggleLive(true); });
        $('#dpgem-button-edit').bind('click', function() { jv_dpgfrontend_editmode_toggleLive(false); });
        $('#dpgem-button-shrink').bind('click', function() {
            $('#dpgem-toolbar').children('div').each(function() { $(this).fadeOut('fast'); });
            $('.dpgem-button-shrink').fadeOut('fast');
            $('#dpgem-toolbar').animate({height: '13px'}, 'slow', function() {
                $('.dpgem-button-blow').fadeIn('fast');
            });
            x_dpgem_set_toolbar_status('hidden', true, function(z){});
            $('.mceExternalToolbar').each(function() { $(this).hide(); });
        });
        $('#dpgem-button-blow').bind('click', function() {
            $('#dpgem-toolbar').children('div').each(function() {
                if (!$(this).hasClass('button-hidden')) {
                    $(this).fadeIn('fast');
                }
            });
            $('.dpgem-button-blow').fadeOut('fast');
            $('#dpgem-toolbar').animate({height: '66px'}, 'slow', function() {
                $('.dpgem-button-shrink').fadeIn('fast');
            });
            x_dpgem_set_toolbar_status('hidden', false, function(z){});
            $('.mceExternalToolbar').each(function() { $(this).hide(); });
        });
        $('#dpgem-button-logout').bind('click', function() {
            x_dpgem_call_factory('logout', function(z){
                location.reload();
            });
        });

        // read status of toolbar and trigger events that switch between the
        // different modes
        var toolbar_hidden = false;
        var toolbar_live = false;
        x_dpgem_get_toolbar_status('hidden', function(z) { toolbar_hidden = z; });
        x_dpgem_get_toolbar_status('live', function(z) { toolbar_live = z; });
        if (toolbar_live) {
            // setup sizes of editable elements at web page and
            // switch beween inputs and plain text
            dpgem_editMode_Active = false;
            jv_dpgfrontend_editmode_setup();

            if (!doNotInitialize) {
                // switch between "edit" and "live" button
                // (only when class is initialized since the toolbar is always
                // present, even if the content is XMLHttpRequest-reloaded
                $('#dpgem-button-edit').removeClass('button-hidden');
                $('#dpgem-button-accept').addClass('button-hidden');
                $('#dpgem-button-edit').toggle();
                $('#dpgem-button-accept').toggle();
            }
        } else {
            // setup sizes of editable elements at web page
            dpgem_editMode_Active = true;
            jv_dpgfrontend_editmode_setup();

            // close tinyMCE instances that were closed before
            jv_dpgfrontend_editmode_close_tinyMCE_instances();
        }
        if (toolbar_hidden)
            $('#dpgem-button-shrink').trigger('click');
        // ---
        // end : "handle toolbar" ]]

        // [[ begin : "handle auxiliary layer"
        // ---
        // bind other events to special DOM elements
            js_dpgfrontend_editmode_remove_encompassing_hyperlinks();
            js_dpgfrontend_editmode_remove_encompassing_inline_elements();

            // all : hide contect menus
            $(document).click(function(){ $('.dpgem-imgbtn-menu-context').hide(); });

            // all : simple text fields
            $('.dpgem-simple-text').each(
                function(i) {
                    $(this).bind({
                      click: function(e) {
                        if ($(this).parent().hasClass('dpgem-invisible-though')) {
                            e.preventDefault();
                        }
                      },
                      keypress: function(e) {
                        if (e.which == '13') {
                            if ($(this).hasClass('dpgem-simple-text-menu')) {
                                var eid = $(this).attr('id');
                                var tid = null;
                                var tval = $(this).val();
                                var timg;
                                var stregexp = /^T(\w+)/;
                                stregexp.exec(eid);
                                tid = RegExp.$1;
                                jv_dpgfrontend_editmode_save_id($(this).attr('id'));
                                js_dpgfrontend_editmode_undo_change($(this).attr('id'));
                                $(this).parent().toggle();
                                $('#' + tid).find('img.dpgem-imgbtn-menu-mode').each(function(){ timg = '<img' + $(this).getAttributes() + '/>'; });
                                $('#' + tid).find('a').each(function(){ $(this).html(tval + ' ' + timg); });
                                $('#' + tid).toggle();
                            }
                            e.preventDefault();
                            return false;
                        }
                      },
                      focus: function(e) {
                        js_dpgfrontend_editmode_notify_change($(this).attr('id'));
                      }
                    });
                }
            );

            // menu : context menu
            $('.dpgem-imgbtn-menu-mode').each(
                function(i) {
                    $(this).bind({
                      click: function(e) {
                        var eid = $(this).attr('id').replace(/MBTN/, "");
                        $('.dpgem-imgbtn-menu-context').hide();
                        $('#MC' + eid).css('left', e.pageX + 'px');
                        $('#MC' + eid).css('top', e.pageY + 'px');
                        $('#MC' + eid).toggle();
                        e.preventDefault();
                        return false;
                      }
                    });
                }
            );

            // menu : context menu : buttons
            $('.dpgem-imgbtn-menu-entry').each(
                function(i) {
                    $(this).bind({
                      click: function(e) {
                        var eid = false;
                        if ($(this).hasClass('dpgem-imgbtn-menu-entry-1')) {
                            var eid = $(this).attr('id').replace(/MBTN1/, "");
                            $('#' + eid).toggle();
                            $('#T' + eid).parent().toggle();
                        }
                        if ($(this).hasClass('dpgem-imgbtn-menu-entry-2')) {
                            var eid = $(this).attr('id').replace(/MBTN2/, "");
                            var stregexp = /(\w+)_EID\w+_ID(\w+)/;
                            $('#mfl-edit').show();
                            $('#mfl-new').hide();
                            $('#submit_mode').attr('value', 'edit');
                            stregexp.exec(eid);
                            jv_dpgfrontend_editmode_open_edit_dialog(RegExp.$2);
                        }
                        if ($(this).hasClass('dpgem-imgbtn-menu-entry-3')) {
                            var eid = $(this).attr('id').replace(/MBTN3/, "");
                            var stregexp = /(\w+)_EID\w+_ID(\w+)/;
                            $('#mfl-edit').hide();
                            $('#mfl-new').show();
                            $('#submit_mode').attr('value', 'create-successor');
                            stregexp.exec(eid);
                            jv_dpgfrontend_editmode_open_create_dialog(RegExp.$2);
                        }
                        if ($(this).hasClass('dpgem-imgbtn-menu-entry-4')) {
                            var eid = $(this).attr('id').replace(/MBTN4/, "");
                            var stregexp = /(\w+)_EID\w+_ID(\w+)/;
                            $('#mfl-edit').hide();
                            $('#mfl-new').show();
                            $('#submit_mode').attr('value', 'create-same-level');
                            stregexp.exec(eid);
                            jv_dpgfrontend_editmode_open_create_dialog(RegExp.$2);
                        }
                        if ($(this).hasClass('dpgem-imgbtn-menu-entry-6')) {
                			var eid = $(this).attr('id').replace(/MBTN6/, "");
	                        var stregexp = /(\w+)_EID\w+_ID(\w+)/;
	                        stregexp.exec(eid);
	                        var groupid = RegExp.$2;
	                        var dodelete = confirm(dpgem_languageDef['LANG_EM_JS_DELETE_GROUP_ASK']);
	                        if (dodelete) {
                                var dodeleteREFID = confirm(dpgem_languageDef['LANG_EM_JS_DELETE_REFID_ASK']);

                                show_presentation_effect();
                                process_dialog();

								x_dpgem_delete_group(groupid, dodeleteREFID, function(z){
									if (!z) {
										jv_dpgfrontend_editmode_error(dpgem_languageDef['LANG_EM_JS_ERROR_NO_RIGHTS']);
									}
								});

							    jv_dpgfrontend_editmode_reload();
							}
                        }
                        if ($(this).hasClass('dpgem-imgbtn-menu-entry-7')) {
                            var eid = $(this).attr('id').replace(/MBTN7/, "");
                            var stregexp = /(\w+)_EID\w+_ID(\w+)/;
                            stregexp.exec(eid);
                            jv_dpgfrontend_editmode_open_article_dialog(RegExp.$2, true);
                        }
                        if ($(this).hasClass('dpgem-imgbtn-menu-entry-X')) {
                            var eid = $(this).attr('id').replace(/MBTNX/, "");
                        }
                        if (eid) {
                            $('#MC' + eid).toggle();
                            e.preventDefault();
                            return false;
                        }
                      }
                    });
                }
            );
            $('.dpgem-imgbtn-menu-entry').each(
                function(i) {
                    if ($(this).hasClass('dpgem-imgbtn-menu-entry-5')) {
                        var eid = $(this).attr('id').replace(/MBTN5/, "");
                        var stregexp = /(\w+)_EID\w+_ID(\w+)/;
                        stregexp.exec(eid);
                        $(this).attr('target', '_blank');
                        $(this).attr('href', dpgem_pathTo_Root + 'index.php?show=3&take=' + RegExp.$2);
                    }
                }
            );

            // menu : em-layer : article : close
            $('#close_menu_article_form').bind('click', function(e) {
                var formObj = document.forms['Inline_Article_Manipulation_Form'];
                var no_refid = formObj.no_refid.value;
                if (jQuery.trim(no_refid) == '') {
                    $('#article_edit_form').fadeOut('fast');
                    $('#group_edit_form').fadeIn('slow');
                } else {
                    close_dialog('article_edit_form');
                }
                return false;
            });

            // menu : em-layer : article : save
            $('#submit_menu_article_form').bind('click', function(e) {
                var gid = document.forms['Inline_Article_Manipulation_Form'].group_id.value;
                var formObj = document.forms['Inline_Article_Manipulation_Form'];
                var ok = 0;

                x_dpgem_create_article(
                    gid,
                    formObj.article_title.value,
                    tinyMCE.get('article_lead').getContent(),
                    tinyMCE.get('article_text').getContent(),
                    formObj.article_searchkeys.value,
                    formObj.article_index.value,
                    formObj.article_public_from_date.value + ' ' + formObj.article_public_from_time.value,
                    formObj.article_public_until_date.value + ' ' + formObj.article_public_until_time.value,
                    formObj.article_isathome.checked,
					{
						0: formObj.article_show_menu.checked,
						1: formObj.article_show_lists.checked
					},
                    formObj.article_meta_title.value,
                    formObj.article_meta_keywords.value,
                    formObj.article_meta_description.value,
                    function(z) {ok = z;}
                );

                if (!ok)
                    jv_dpgfrontend_editmode_error(
                        jQuery.trim(formObj.article_title.value) == ''?
                            dpgem_languageDef['LANG_EM_JS_ERROR_NO_ARTICLE_NAME']:
                            dpgem_languageDef['LANG_EM_JS_ERROR_NO_RIGHTS']
                    )
                else {
                    var no_refid = formObj.no_refid.value;
                    if (jQuery.trim(no_refid) == '') {
    					// created article is a group content
                        $('#assign_group_content').hide();
    					$('#group_content_assignment').show();
    					document.forms['Inline_Group_Manipulation_Form'].group_content.value = ok;
                		document.forms['Inline_Group_Manipulation_Form'].group_content_is_start.checked = false;
                		document.forms['Inline_Group_Manipulation_Form'].edit_resume_input_article.value = $('#edit_nonempty_content_value').attr('value') + ' ' + ok;
                        $('#article_edit_form').fadeOut('fast');
                        $('#group_edit_form').fadeIn('slow');
                    } else {
                        // created article was created as usual article within a group
                        jv_dpgfrontend_editmode_save();
                        jv_dpgfrontend_editmode_reload();
                        close_dialog('article_edit_form');
                    }
                }

                return false;
            });

			// menu : em-layer : group : create content
            $('#create_group_content').bind('click', function(e) {
                jv_dpgfrontend_editmode_open_article_dialog();
                return false;
            });

            // menu : em-layer : group : assign content
            $('#assign_group_content').bind('click', function(e) {
                $(this).hide();
				$('#group_content_assignment').show();
                return false;
            });

            // menu : em-layer : group : close
            $('#close_menu_edit_form').bind('click', function(e) {
                close_dialog('group_edit_form');
                return false;
            });

            // menu : em-layer : group : save
            $('#submit_menu_edit_form').bind('click', function(e) {
                var gid = document.forms['Inline_Group_Manipulation_Form'].group_id.value;
                var formObj = document.forms['Inline_Group_Manipulation_Form'];
                var ok = true;

                if ($('#submit_mode').val() == 'edit') {
                    x_dpgem_save_group_data(gid, 'name', formObj.group_name.value, function(z) {ok = !z? false: ok;});
                    x_dpgem_save_group_data(gid, 'shorttext', tinyMCE.get('group_shorttext').getContent(), function(z) {ok = !z? false: ok;});
                    x_dpgem_save_group_data(gid, 'refid', formObj.group_content.value, function(z) {ok = !z? false: ok;});
                    x_dpgem_save_group_data(gid, 'refid_is_start', formObj.group_content_is_start.checked? 1: 0, function(z) {ok = !z? false: ok;});
                    x_dpgem_save_group_data(gid, 'public', formObj.group_public.selectedIndex + 1, function(z) {ok = !z? false: ok;});
                    x_dpgem_save_group_data(gid, 'public_from', formObj.group_public_from_date.value + ' ' + formObj.group_public_from_time.value, function(z) {ok = !z? false: ok;});
                    x_dpgem_save_group_data(gid, 'public_until', formObj.group_public_until_date.value + ' ' + formObj.group_public_until_time.value, function(z) {ok = !z? false: ok;});
                    x_dpgem_save_group_data(gid, 'index', formObj.group_index.value, function(z) {ok = !z? false: ok;});
                    x_dpgem_save_group_data(gid, 'meta_title', formObj.group_meta_title.value, function(z) {ok = !z? false: ok;});
                    x_dpgem_save_group_data(gid, 'meta_keywords', formObj.group_meta_keywords.value, function(z) {ok = !z? false: ok;});
                    x_dpgem_save_group_data(gid, 'meta_description', formObj.group_meta_description.value, function(z) {ok = !z? false: ok;});
                } else {
                    x_dpgem_create_group(
                        gid,
                        formObj.group_name.value,
                        tinyMCE.get('group_shorttext').getContent(),
                        formObj.group_content.value,
                        formObj.group_content_is_start.checked? 1: 0,
                        -1,
                        'LEFT',
                        formObj.group_public.selectedIndex + 1,
                        formObj.group_public_from_date.value + ' ' + formObj.group_public_from_time.value,
                        formObj.group_public_until_date.value + ' ' + formObj.group_public_until_time.value,
                        false,
                        formObj.group_index.value,
                        !($('#submit_mode').val() == 'create-successor'),
                        formObj.group_meta_title.value,
                        formObj.group_meta_keywords.value,
                        formObj.group_meta_description.value,
                        function(z) {ok = z;}
                    );
                }

                if (!ok)
                    jv_dpgfrontend_editmode_error(
                        jQuery.trim(formObj.group_name.value) == ''?
                            dpgem_languageDef['LANG_EM_JS_ERROR_NO_GROUP_NAME']:
                            dpgem_languageDef['LANG_EM_JS_ERROR_NO_RIGHTS']
                    )
                else {
                    jv_dpgfrontend_editmode_save();
                    jv_dpgfrontend_editmode_reload();
                    close_dialog('group_edit_form');
                }
                return false;
            });

            // all : add-to-list : add, buttons
            $('.dpgem-button-add-to-list').each(
                function(i) {
                    $(this).bind({
                      click: function(e) {
                        var eid = $(this).attr('id');

                        show_presentation_effect();

                    	$('#CONTAINER_' + eid).css('top', Math.max(50, Math.floor($(window).height() / 2) + $(window).scrollTop() - $('#CONTAINER_' + eid).height() / 2 - 100));
                        $('#CONTAINER_' + eid).css('left', Math.max(50, Math.floor($(window).width() / 2) + $(window).scrollLeft() - $('#CONTAINER_' + eid).width() / 2));

                        $('#CONTAINER_' + eid).slideDown('slow');

                        e.preventDefault();
                        return false;
                      }
                    });
                    $('#ABORT_' + $(this).attr('id')).unbind('click');
                    $('#ABORT_' + $(this).attr('id')).click(function(){ close_dialog('CONTAINER_' + $(this).attr('id').replace(/ABORT_/, "")); });

                    $('#ADD_' + $(this).attr('id')).unbind('click');
                    $('#ADD_' + $(this).attr('id')).click(function(){
                        var gid = $('#SELECT_' + $(this).attr('id').replace(/ADD_/, "")).find(':selected').val();
                        $('#CONTAINER_' + $(this).attr('id').replace(/ADD_/, "")).hide();
                        jv_dpgfrontend_editmode_open_article_dialog(gid, true);
                    });
                }
            );

            // all : article delete buttons
            $('.dpgem-imgbtn-delete').each(
                function(i) {
                    $(this).bind({
                      click: function(e) {
                        var eid = $(this).attr('id').replace(/BTN_/, "");
                        var stregexp = /(\w+)_EID\w+_ID(\w+)/;
                        stregexp.exec(eid);
                        var id = RegExp.$2;
                        var dodelete = confirm(dpgem_languageDef['LANG_EM_JS_DELETE_ELEMENT_ASK']);
                        if (dodelete) {
							show_presentation_effect();
                            process_dialog();

                            x_dpgem_delete_article(id, function(z){
								if (!z) {
									jv_dpgfrontend_editmode_error(dpgem_languageDef['LANG_EM_JS_ERROR_NO_RIGHTS']);
								}
							});

                            jv_dpgfrontend_editmode_reload();
						}
                        e.preventDefault();
                        return false;
                      }
                    });
                }
            );
        // ---
        // end : "handle auxiliary layer" ]]

        // predefine styles for the menu context menu and remove all
        // encompassing styles
        jv_dpgfrontend_editmode_setup_css();

        // handle common <object> tags embedding flash or similar
        jv_dpgfrontend_editmode_setup_object_embeddings();
    }

    /* -------------------------------------------------------------------------
     *
     *  function definitions
     *
     * -------------------------------------------------------------------------
     */

    /**
     * jv_dpgfrontend_editmode_setup()
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_setup() {
        // if edit mode is inactive, then hide text fields and show
        // div layer instead
        if (!dpgem_editMode_Active) {
            jv_dpgfrontend_editmode_toggleMode();
        }

        // resize text fields
        jv_dpgfrontend_editmode_resizeFields();
    }

    /**
     * jv_dpgfrontend_editmode_toggleMode()
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_toggleMode() {
        $('.dpgem-saveable-container').each(function(i) {
            if (!$(this).hasClass('dpgem-invisible-though'))
                $(this).toggle();
            else
                $(this).hide();
        });

        $('.dpgem-invisible').each(function(i) {
            if (!$(this).hasClass('dpgem-visible-though'))
                $(this).toggle();
            else
                $(this).show();
        });

        $('.dpgem-imgbtn-menu-mode').toggle();
        $('.dynpg_A_edit_mode').toggle();
        $('.dpgem-button-add-to-list').toggle();

        js_dpgfrontend_editmode_remove_encompassing_hyperlinks();
        js_dpgfrontend_editmode_remove_encompassing_inline_elements();
    }

    /**
     * jv_dpgfrontend_editmode_close_tinyMCE_instances
     *
     * Hide closed tinyMCE instances
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_close_tinyMCE_instances() {
        $('.dpgem-saveable-container').each(function(i) {
            var closed = false;
            var eid = null;
            $(this).children('textarea').each(function(){ eid = $(this).attr('id'); });
            if (eid) {
                var rE = /^T(\w+)_EID(\w+)_ID(\d+)/;
                rE.exec(eid);
                ttype = RegExp.$1;
                tiid = RegExp.$3;
                closed = !(jQuery.inArray(ttype + '-' + tiid, dpgem_visibleTinyMCEInstances) >= 0);
                if (closed)
                    $(this).hide();
            }
        });
        $('.dpgem-invisible').each(function(i) {
            var closed = false;
            var tid = $(this).attr('id');
            var eid = 'T' + $(this).attr('id');
            if (eid) {
                if (!$('#' + eid).hasClass('dpgem-tinymce-editor'))
                    return;
                var rE = /^T(\w+)_EID(\w+)_ID(\d+)/;
                rE.exec(eid);
                ttype = RegExp.$1;
                tiid = RegExp.$3;
                closed = !(jQuery.inArray(ttype + '-' + tiid, dpgem_visibleTinyMCEInstances) >= 0);
                if (closed) {
                    $(this).unbind('click');
                    $(this).click(function(e){
                        $('#' + eid).parent().toggle();
                        $('#' + tid).toggle();
                        x_dpgem_load_tinyMCE(eid, function(){});
                        e.preventDefault();
                    });
                    $(this).css('cursor', 'pointer');
                    $(this).attr('title', $("<div/>").html(dpgem_languageDef['LANG_EM_JS_OPEN_TINYMCE_INSTANCE']).text());
                    $(this).toggle();
                    $(this).show();
                }
            }
        });
    }

    /**
     * jv_dpgfrontend_editmode_resizeFields();
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_resizeFields() {
        var tinyMCEIFrameMargin = 0;
        var tinyMCEIFrameOffset = 10;
        var textFieldOffset = -2;

        // resize tinymce instances
        $('.dpgem-tinymce-editor').each(
            function(i) {
                // we render the tinyMCE instances manually
                try {
                    tinyMCE.get($(this).attr('id')).remove();
                } catch (e) {}
                var tinyMCEObj = new tinyMCE.Editor($(this).attr('id'), settings);

                tinyMCEObj.onInit.add(function(ed, e){
                    $('#' + ed.id + '_tbl').find('*').each(function(){
                        _jv_set_trbl_prop($(this), 'border', '0');
                    });
                    $('#' + ed.id + '_tbl').find('.mceStatusbar').css('background-color', 'white');
                    $('#' + ed.id + '_path_row').hide();
                    _jv_set_trbl_prop($('#' + ed.id + '_tbl'), 'border', '0');
                    ed.addShortcut('ctrl+s', '', function(){
                        ed.execCommand('femSave', false);
                    });
                    ed.addCommand('femSave', function(ui, v){
                        jv_dpgfrontend_editmode_save_id(ed.id);
                    });
                    ed.focus();
                });
                tinyMCEObj.render();

                // read and set sizes of the editors
                var stobj = $('#' + $(this).attr('id')); // the tinymce editor
                var stdobj = $('#' + $(this).attr('id').slice(1)); // the div container
                var stwidth = stdobj.outerWidth(true) + tinyMCEIFrameOffset * 2;
                stobj.height(stdobj.outerHeight(true) + tinyMCEIFrameMargin * 2);

                // @note: Choosing the parent width seems to work much better.
                // if (stwidth > stobj.width())
                //    stobj.width(stwidth);
                if (stdobj.parent())
                    stobj.width(stdobj.parent().outerWidth(true));
                else
                    stobj.width(stwidth);
            }
        );

        // resize simple text fields
        $('.dpgem-simple-text').each(
            function(i) {
                var stobj = $('#' + $(this).attr('id')); // the text input field
                var stdobj = $('#' + $(this).attr('id').slice(1)); // the div container
                stobj.css('font-size', stdobj.css('font-size'));

                // @note: Choosing the parent width seems to work much better.
                // stobj.width(stdobj.outerWidth(true));
                var w = 0;
                if (stdobj.parent())
                    w = stdobj.parent().outerWidth(true) + textFieldOffset * 2;
                else
                    w = stwidth;
                stobj.width(Math.max(16, w - 16));
            }
        );
    }

    /**
     * jv_dpgfrontend_editmode_toggleLive(editToLive: boolean)
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_toggleLive(editToLive) {
        // save toolbar status
        x_dpgem_set_toolbar_status('live', editToLive, function(z){});

        // show loading effects
        show_presentation_effect();
        process_dialog();

        // perform actions
        if (editToLive) {
            // save data if we switch from edit mode to live mode
            jv_dpgfrontend_editmode_save(true);

            // set global editMode property
            dpgem_editMode_Active = false;

            // reload content
            jv_dpgfrontend_editmode_reload();
        } else {
            // set global editMode property
            dpgem_editMode_Active = true;

            // switch beween inputs and plain text
            jv_dpgfrontend_editmode_toggleMode();

            // switch between "edit" and "live" button
            $('#dpgem-button-accept').removeClass('button-hidden');
            $('#dpgem-button-edit').addClass('button-hidden');
            $('#dpgem-button-accept').toggle();
            $('#dpgem-button-edit').toggle();

            // resize text fields
            jv_dpgfrontend_editmode_resizeFields();

            // close tinyMCE instances that were closed before
            jv_dpgfrontend_editmode_close_tinyMCE_instances();
        }

        // unshow the loading effects
        close_dialog();
    }

    /**
     * jv_dpgfrontend_editmode_save()
     *
     * This method implements the bridge between JS and PHP routines. It
     * therefore calls methods registered in the SAJAX framework in order
     * execute correspondent PHP functionalities which save the data into the
     * DB. In order to add new attributes, feel free to modify the switch
     * statement within this function.
     *
     * @access private
     * @return boolean
     **/
    function jv_dpgfrontend_editmode_save(noeffects) {
        var error = false;

        // show loading effects
        if (!noeffects) {
            show_presentation_effect();
            process_dialog();
        }

        // save data to database
        $('.dpgem-saveable').each(
            function(i) {
                var stid = $(this).attr('id');
                var stobj = $('#' + stid); // the saveable content item
                var stdobj = $('#' + stid.slice(1)); // the div container
                var stregexp = /T(\w+)_EID\w+_ID(\w+)/; // the saveable item identification

                stregexp.exec(stid);

                var stident = RegExp.$1;
                var stoid = RegExp.$2;
                var stattr = '';
                var sttype = 'a-simple';

                // The current text field has not been edited, so we can
                // skip it.
                if (jQuery.inArray(stid, dpgem_editedFields) < 0) {
                    return;
                }

                // This is where we choose between the different attributes
                // and modes (article or group). After choosing the correspondent
                // attribute and type, the corresponding SAJAX routine is called.
                // In order to add further attributes extend this switch
                // statement along with the following references.
                // @see frontend.em_functions.inc.php
                // @see getcontent.php::includeEditMode()
                switch(stident) {
                    // the article attributes that can be changed
                    case 'ATIT': stattr = 'title'; sttype = 'a-simple'; break;
                    case 'ASKS': stattr = 'searchkeys'; sttype = 'a-simple'; break;
                    case 'ALED': stattr = 'lead'; sttype = 'a-long'; break;
                    case 'ACNT': stattr = 'text'; sttype = 'a-long'; break;
                    case 'AIDX': stattr = 'index'; sttype = 'a-simple'; break;

                    // the group attributes that can be changed
                    case 'GNAM': stattr = 'name'; sttype = 'g-simple'; break;
                    case 'GSHT': stattr = 'shorttext'; sttype = 'g-long'; break;
                    default: return false;
                }

                if (sttype == 'a-simple') {
                    x_dpgem_save_article_data(
                        stoid,
                        stattr,
                        $(this).val(),
                        function(z) { error = !z? true: error; }
                    );
                }

                if (sttype == 'a-long') {
                    var thisEd = tinyMCE.get(stid);
                    x_dpgem_save_article_data(
                        stoid,
                        stattr,
                        thisEd.getContent(),
                        function(z) { error = !z? true: error; }
                    );
                }

                if (sttype == 'g-simple') {
                    x_dpgem_save_group_data(
                        stoid,
                        stattr,
                        $(this).val(),
                        function(z) { error = !z? true: error; }
                    );
                }

                if (sttype == 'g-long') {
                    var thisEd = tinyMCE.get(stid);
                    x_dpgem_save_group_data(
                        stoid,
                        stattr,
                        thisEd.getContent(),
                        function(z) { error = !z? true: error; }
                    );
                }
            }
        );

        // throw error if necessary
        if (error)
            jv_dpgfrontend_editmode_error(dpgem_languageDef['LANG_EM_JS_ERROR_RIGHTS_MISSING']);

        // unshow the loading effects
        if (!noeffects)
            close_dialog();

        // clear array of edited fields
        dpgem_editedFields = new Array();

        return true;
    }

    /**
     * jv_dpgfrontend_editmode_save_id()
     *
     * Do only save a single element using
     * jv_dpgfrontend_editmode_save().
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_save_id(id) {
        var dpgem_editedFields_ = dpgem_editedFields;
        dpgem_editedFields = new Array();
        dpgem_editedFields[0] = id;
        var b = jv_dpgfrontend_editmode_save();
        dpgem_editedFields = dpgem_editedFields_;
        return b;
    }

    /**
     * ajaxSetup()
     *
     * Handle responses by server after a XMLHttpRequest request.
     *
     * @access private
     * @return void
     **/
    $.ajaxSetup({
        error:function(x,e){
            if (x.status == 0) {
                // alert('You are offline!!\n Please Check Your Network.');
            } else if (x.status == 404){
                // alert('Requested URL not found.');
            } else if (x.status == 500){
                // workaround if XMLHTTPRequest fails but returns
                // the correct content
                var data = x.responseText;
                jv_dpgfrontend_editmode_reload_extract(data);
            } else if (e == 'parsererror'){
                // alert('Error.\nParsing JSON Request failed.');
            } else if (e == 'timeout'){
                // alert('Request Time out.');
            } else {
                // alert('Unknow Error.\n'+x.responseText);
            }
        }
    });

    /**
     * jv_dpgfrontend_editmode_reload()
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_reload() {
        // @see load() (@url: http://api.jquery.com/load/)
        // @see jQuery.get() (@url: http://api.jquery.com/jQuery.get/)
        // @see jQuery (@url: http://api.jquery.com/jQuery/)

        // Fetch new data via XMLHttpRequest from dpgem_currentPageURL
        $.get(dpgem_currentPageURL, function(data) {
            jv_dpgfrontend_editmode_reload_extract(data);
        });
    }

    /**
     * jv_dpgfrontend_editmode_reload_extract()
     *
     * Extract the necessary data from parameter "data"
     * in order to add it to the current page.
     *
     * @access private
     * @return void
     **/
    function _jv_handle_embeddings(data) {
        // handle dynamically added flash content using dynpg specific
        // write*** methods within swfobject.js
        var scriptExec = /(<script[^>]*>[\s\n]*write(Flash|ShockWave|QuickTime|RealMedia|WindowsMedia|Embed)\(([^\)]+)\)[^<]*<\/script>)/i;

        while(scriptExec.test(data)) {
            // extract all script tags that possibly embed an <object>-tag
            // from "data"
            scriptExec.exec(data);

            var aA = RegExp.$1;
            var aT = RegExp.$2;
            var aO = RegExp.$3;
            var objTag = '';

            // execute the corresponding js-function but buffer output
            // written via document.write() by write***()
            document.write = function(c) { objTag += c; };
            jQuery.globalEval('write' + aT + '(' + aO + ');');

            // we are now in the position replace the <script> embedding
            // by the dynamically obtained <object> tag in "objTag"
            data = data.replace(aA, objTag);
        }

        return data;
    }
    function jv_dpgfrontend_editmode_reload_extract(data) {
        // extract the body content from the fetched data
        var body_b = data.search(/<body[^>]*>/);
        var body_e = data.search(/<\/body[^>]*>/);
        data = data.slice(body_b, body_e);
        data = data.replace(/<body[^>]*>/, '');

        // handle dynamically added <object>-tags by swfobject.js
        // in order to show them within the edit mode, too
        data = _jv_handle_embeddings(data);

        // disallow the document.write() function, otherwise
        // jQuery/Ajax will fail to load the content correctly
        document.write = function(c) {};

        // replace old body content with new
        try {
            $('body').html(data)
        } catch (e) {}
        $('body').append(dpgem_layers(dpgem_editMode_Active, true));

        // reload tinyMCE instances
        // @alternative: tinymce.execCommand('mceToggleEditor', false, 'textarea-name');
        tinyMCE.init(settings);

        // init edit mode routines with inactive edit mode now
        dpgem_init(dpgem_editMode_Active, true);

        // we need to resize the fields manually b e f o r e
        // creating the tinyMCE instances within the next step
        jv_dpgfrontend_editmode_resizeFields();
    }

    /**
     * jv_dpgfrontend_editmode_error()
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_error(msg) {
        $('#dpgem_error_dialog').html(dpgem_languageDef['LANG_EM_JS_ERROR'] + '<br />' +  msg);
        $("#dpgem_error_dialog").css('top', Math.max(50, Math.floor($(window).height() / 2) + $(window).scrollTop() - $("#dpgem_error_dialog").height() / 2 - 100));
        $("#dpgem_error_dialog").css('left', Math.max(50, Math.floor($(window).width() / 2) + $(window).scrollLeft() - $("#dpgem_error_dialog").width() / 2));
        $('#dpgem_error_dialog').fadeIn('fast');
        window.setTimeout('$("#dpgem_error_dialog").fadeOut("slow")', 2500);
    }

    /**
     * jv_dpgfrontend_editmode_success()
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_success(msg) {
        alert(dpgem_languageDef['LANG_EM_JS_SUCCESS'] + msg);
    }

    /**
     * jv_dpgfrontend_editmode_open_edit_dialog()
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_open_edit_dialog(vId) {
        $('#group_edit_form').hide();

        try {
            tinyMCE.get('group_shorttext').remove();
        } catch (ex) {}

        x_dpgem_read_group_values(vId, function(z) {
            document.forms['Inline_Group_Manipulation_Form'].group_id.value = vId;
            document.forms['Inline_Group_Manipulation_Form'].group_name.value = z['NAME'];
            document.forms['Inline_Group_Manipulation_Form'].group_content.value = (parseFloat(z['REFID']) <= 0 || isNaN(parseFloat(z['REFID'])))? '-1': z['REFID'];
            document.forms['Inline_Group_Manipulation_Form'].group_content_is_start.checked = z['REFID_IS_START'] == 1;
            document.forms['Inline_Group_Manipulation_Form'].edit_resume_input_article.value = (parseFloat(z['REFID']) <= 0 || isNaN(parseFloat(z['REFID'])))? $('#edit_empty_content_value').attr('value'): $('#edit_nonempty_content_value').attr('value') + ' ' + z['REFID'];
            document.forms['Inline_Group_Manipulation_Form'].group_public.selectedIndex = Math.max(0, parseFloat(z['PUBLIC']) - 1);
            document.forms['Inline_Group_Manipulation_Form'].group_index.value = z['INDEX'];
            document.forms['Inline_Group_Manipulation_Form'].group_public_from_date.value = z['PUBLIC_FROM_DATE'];
            document.forms['Inline_Group_Manipulation_Form'].group_public_from_time.value = z['PUBLIC_FROM_TIME'];
            document.forms['Inline_Group_Manipulation_Form'].group_public_until_date.value = z['PUBLIC_UNTIL_DATE'];
            document.forms['Inline_Group_Manipulation_Form'].group_public_until_time.value = z['PUBLIC_UNTIL_TIME'];
            document.forms['Inline_Group_Manipulation_Form'].group_meta_title.value = z['META_TITLE'];
            document.forms['Inline_Group_Manipulation_Form'].group_meta_keywords.value = z['META_KEYWORDS'];
            document.forms['Inline_Group_Manipulation_Form'].group_meta_description.value = z['META_DESCRIPTION'];

            if ((parseFloat(z['REFID']) <= 0 || isNaN(parseFloat(z['REFID'])))) {
				$('#group_content_assignment').hide();
				$('#assign_group_content').show();
			} else {
				$('#group_content_assignment').show();
				$('#assign_group_content').hide();
			}

            // @REMARK
            // The following seems to be too cumbersome but it was the only possibility to
            // call this method again after already having executed the save routines
            // by pressing the "Save" button (and thus data was reloaded
            // via "jv_dpgfrontend_editmode_reload_extract"). The problem is, that
            // this has the consequence that in forthcoming procedures
            // no simple tinyMCE.get('group_shorttext').setContent() is possible
            // due to unloaded document fragments.
            var tinyMCE_group_shorttext = new tinyMCE.Editor("group_shorttext", settings);
            tinyMCE_group_shorttext.onInit.add(function(ed, e){
                ed.setContent(z['SHORTTEXT']);
                ed.focus();
            });
            tinyMCE_group_shorttext.render();
        });

        show_presentation_effect();

    	$("#group_edit_form").css('top', Math.max(50, Math.floor($(window).height() / 2) + $(window).scrollTop() - $("#group_edit_form").height() / 2 - 100));
        $("#group_edit_form").css('left', Math.max(50, Math.floor($(window).width() / 2) + $(window).scrollLeft() - $("#group_edit_form").width() / 2));

        $('#group_edit_form').slideDown('slow');

        return false;
    }

    /**
     * jv_dpgfrontend_editmode_open_create_dialog()
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_open_create_dialog(vId) {
        $('#group_edit_form').hide();

        try {
            tinyMCE.get('group_shorttext').remove();
        } catch (ex) {}

        var cD = new Date();

        document.forms['Inline_Group_Manipulation_Form'].group_id.value = vId;
        document.forms['Inline_Group_Manipulation_Form'].group_name.value = '';
        document.forms['Inline_Group_Manipulation_Form'].group_content.value = '-1';
        document.forms['Inline_Group_Manipulation_Form'].group_content_is_start.checked = false;
        document.forms['Inline_Group_Manipulation_Form'].edit_resume_input_article.value = $('#edit_empty_content_value').attr('value');
        document.forms['Inline_Group_Manipulation_Form'].group_public.selectedIndex = 0;
        document.forms['Inline_Group_Manipulation_Form'].group_index.value = 0;
        x_dpgem_call_factory('getCurrentDate', false, function(z){ document.forms['Inline_Group_Manipulation_Form'].group_public_from_date.value = z; });
        x_dpgem_call_factory('getCurrentTime', false, function(z){ document.forms['Inline_Group_Manipulation_Form'].group_public_from_time.value = z; });
        document.forms['Inline_Group_Manipulation_Form'].group_public_until_date.value = '00.00.0000';
        document.forms['Inline_Group_Manipulation_Form'].group_public_until_time.value = '00:00:00';
        document.forms['Inline_Group_Manipulation_Form'].group_meta_title.value = '';
        document.forms['Inline_Group_Manipulation_Form'].group_meta_keywords.value = '';
        document.forms['Inline_Group_Manipulation_Form'].group_meta_description.value = '';

        $('#group_content_assignment').hide();
        $('#assign_group_content').show();

        var tinyMCE_group_shorttext = new tinyMCE.Editor("group_shorttext", settings);
        tinyMCE_group_shorttext.onInit.add(function(ed, e){
            ed.setContent('');
            ed.focus();
        });
        tinyMCE_group_shorttext.render();

        show_presentation_effect();

    	$("#group_edit_form").css('top', Math.max(50, Math.floor($(window).height() / 2) + $(window).scrollTop() - $("#group_edit_form").height() / 2 - 100));
        $("#group_edit_form").css('left', Math.max(50, Math.floor($(window).width() / 2) + $(window).scrollLeft() - $("#group_edit_form").width() / 2));

        $('#group_edit_form').slideDown('slow');

        return false;
    }

    /**
     * jv_dpgfrontend_editmode_open_article_dialog()
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_open_article_dialog(vId, no_refid) {
        $('#article_edit_form').hide();
        $('#group_edit_form').hide();

        try {
            tinyMCE.get('article_lead').remove();
        } catch (ex) {}

        try {
            tinyMCE.get('article_text').remove();
        } catch (ex) {}

        if (!vId) {
        	vId = document.forms['Inline_Group_Manipulation_Form'].group_id.value;
		}

		if (no_refid)
		    document.forms['Inline_Article_Manipulation_Form'].no_refid.value = '1';
        else
            document.forms['Inline_Article_Manipulation_Form'].no_refid.value = '';

        document.forms['Inline_Article_Manipulation_Form'].group_id.value = vId;
        document.forms['Inline_Article_Manipulation_Form'].article_title.value = '';
        document.forms['Inline_Article_Manipulation_Form'].article_searchkeys.value = '';
        document.forms['Inline_Article_Manipulation_Form'].article_index.value = '0';
        x_dpgem_call_factory('getCurrentDate', false, function(z){ document.forms['Inline_Article_Manipulation_Form'].article_public_from_date.value = z; });
        x_dpgem_call_factory('getCurrentTime', false, function(z){ document.forms['Inline_Article_Manipulation_Form'].article_public_from_time.value = z; });
        document.forms['Inline_Article_Manipulation_Form'].article_public_until_date.value = '00.00.0000';
        document.forms['Inline_Article_Manipulation_Form'].article_public_until_time.value = '00:00:00';
        document.forms['Inline_Article_Manipulation_Form'].article_isathome.checked = false;
        document.forms['Inline_Article_Manipulation_Form'].article_show_lists.checked = false;
        document.forms['Inline_Article_Manipulation_Form'].article_show_menu.checked = true;
        document.forms['Inline_Article_Manipulation_Form'].article_meta_title.value = '';
        document.forms['Inline_Article_Manipulation_Form'].article_meta_keywords.value = '';
        document.forms['Inline_Article_Manipulation_Form'].article_meta_description.value = '';

        var tinyMCE_article_lead = new tinyMCE.Editor("article_lead", settings);
        tinyMCE_article_lead.onInit.add(function(ed, e){
            ed.setContent('');
            ed.focus();
        });
        tinyMCE_article_lead.render();

        var tinyMCE_article_text = new tinyMCE.Editor("article_text", settings);
        tinyMCE_article_text.onInit.add(function(ed, e){
            ed.setContent('');
            ed.focus();
        });
        tinyMCE_article_text.render();

        show_presentation_effect();

    	$("#article_edit_form").css('top', Math.max(50, Math.floor($(window).height() / 2) + $(window).scrollTop() - $("#article_edit_form").height() / 2 - 100));
        $("#article_edit_form").css('left', Math.max(50, Math.floor($(window).width() / 2) + $(window).scrollLeft() - $("#article_edit_form").width() / 2));

        $('#article_edit_form').slideDown('slow');

        return false;
    }

    /**
     * js_dpgfrontend_editmode_remove_encompassing_inline_elements
     *
     * @access private
     * @return void
     **/
    function js_dpgfrontend_editmode_remove_encompassing_inline_elements() {
        // We want to remove all encompassing inline elements
        // which cannot encompass a div element specified within the
        // menu edit mode layers

        $('.dpgem-imgbtn-menu-text').each(
            function(i) {
                var pT = $(this).parent();
                var ppT = pT.parent();
                var pTN = $(this).parent().get(0).tagName.toLowerCase();
                var pTA = $(this).getAttributes();
                var v = (
                    pTN == 'p'
                    || pTN == 'span'
                    || pTN == 'strong'
                    || pTN == 'em'
                    || pTN == 'b'
                    || pTN == 'i'
                    || pTN == 'h1'
                    || pTN == 'h2'
                    || pTN == 'h3'
                    || pTN == 'h4'
                    || pTN == 'h5'
                    || pTN == 'h6'
                );
                if (!v)
                    return;

                var mT_HTML = $(this).html();
                var mT_Attr = $(this).getAttributes();

                pT.remove();
                ppT.find(pTN).each(function() {
                    if (jQuery.trim($(this).text()) == '')
                        $(this).remove();
                });

                var ppT_HTML = ppT.html();

                ppT.html(
                    '<span' + mT_Attr + '>' +
                        '<' + pTN + pTA + '>' + mT_HTML + '</' + pTN + '>' +
                    '</span>' +
                    ppT_HTML
                );
            }
        );
    }

    /**
     * js_dpgfrontend_editmode_remove_encompassing_hyperlinks()
     *
     * @access private
     * @return void
     **/
    function js_dpgfrontend_editmode_remove_encompassing_hyperlinks() {
        // We want to remove all encompassing hyperlinks
        // and styles from menu specific hyperlinks.

        // remove hyperlinks within the menu inherited from
        // encompassing html tags of the menu entry placeholder
        $('.dpgem-imgbtn-menu-context').find('a').each(
            function(i) {
                if (!$(this).hasClass('dpgem-imgbtn-menu-entry')) {
                    $(this).remove();
                }
            }
        );

        // (try) to insert the encompassing hyperlink of the menu entry
        // into the new 'dpgem-imgbtn-menu-text' layer in order to
        // produce valid DOM and html code
        $('.dpgem-imgbtn-menu-text').each(
            function(i) {
                if ($(this).is(':visible')) {
                    var attr = '';
                    var thtml = '';
                    $(this).parents('a').each(
                        function(i) {
                            var pn = $(this).parent();
                            var cn = $(this).children();
                            attr = $(this).getAttributes();
                            $(this).remove();
                            pn.append(cn);
                            return;
                        }
                    );
                    thtml = $(this).html();
                    $(this).html('<a' + attr + '>' + thtml + '</a>');
                }
            }
        );
        /*
        $('.dpgem-contextmenu-opener').each(
            function(i) {
                if ($(this).css('display') != 'none') {
                    var attr = '';
                    var thtml = '';
                    $(this).parents('a').each(
                        function(i) {
                            var pn = $(this).parent();
                            var cn = $(this).children();
                            $(this).remove();
                            pn.append(cn);
                            return;
                        }
                    );
                }
            }
        );
        */

        // remove all encompassing links from dpgem-saveable-container
        // in order to produce valid html code and deny redirections
        // produced by the browser when clicking inside the input field
        $('.dpgem-saveable-container').each(
            function(i) {
                if ($(this).is(':visible')) {
                    $(this).parents('a').each(
                        function(i) {
                            var pn = $(this).parent();
                            var cn = $(this).children();
                            $(this).remove();
                            pn.append(cn);
                        }
                    );
                }
                $(this).find('a').each(
                    function(i) {
                        var pn = $(this).parent();
                        var cn = $(this).children();
                        $(this).remove();
                        pn.append(cn);
                    }
                );
            }
        );
    }

    /**
     * jv_dpgfrontend_editmode_setup_css()
     *
     * This function removes all necessary styles from child elements
     * of .dpgem-contextmenu-opener and .dpgem-imgbtn-menu-context
     * and applies the dynpg frontend edit mode default styles
     *
     * @access private
     * @return void
     **/
    function _jv_set_trbl_prop(elObj, attr, value) {
        var val = '';
        if (value)
            val = value;

        elObj.css(attr, value);
        elObj.css(attr + '-top', value);
        elObj.css(attr + '-right', value);
        elObj.css(attr + '-bottom', value);
        elObj.css(attr + '-left', value);
    }
    function _jv_dpgfrontend_editmode_remove_styles(elObj, element) {
        // constants
            var CTXT_M_FONT_FAMILY = 'Arial';
            var CTXT_M_FONT_SIZE = '10px';
            var CTXT_M_LINE_HEIGHT = 12;
            var CTXT_M_PADDING = 5;
            var CTXT_M_WIDTH = (120 + 2 * CTXT_M_PADDING) + 'px';
            var CTXT_M_MENU_ENTRIES = 8;
            var CTXT_M_HEIGHT = ((CTXT_M_LINE_HEIGHT + 2 * CTXT_M_PADDING) * CTXT_M_MENU_ENTRIES + 2 * CTXT_M_PADDING - 4) + 'px';

        // remove styles
            _jv_set_trbl_prop(elObj, 'padding', '0px');
            _jv_set_trbl_prop(elObj, 'margin', '0px');
            _jv_set_trbl_prop(elObj, 'border', '0px');

            elObj.css('width', '');
            elObj.css('height', '');
            elObj.css('color', '');
            elObj.css('display', '');
            elObj.css('font-size', '');
            elObj.css('font-weight', '');
            elObj.css('line-height', '');
            elObj.css('font-family', '');
            elObj.css('text-align', '');
            elObj.css('background', '');
            elObj.css('background-color', '');
            elObj.css('background-image', '');
            elObj.css('position', '');
            elObj.css('z-index', '');

        // add new styles
            elObj.css('font-size', CTXT_M_FONT_SIZE);
            elObj.css('font-weight', 'normal');
            elObj.css('line-height', CTXT_M_LINE_HEIGHT + 'px');
            elObj.css('font-family', CTXT_M_FONT_FAMILY);
            elObj.css('color', 'white');

        // add specific styles
            if (element.toLowerCase() == 'p') {
                if (elObj.css('width') != '')
                    elObj.css('width', CTXT_M_WIDTH);
                if (elObj.css('height') != '')
                    elObj.css('height', CTXT_M_LINE_HEIGHT + 'px');

                elObj.css('padding', CTXT_M_PADDING + 'px');
                elObj.css('margin', '0');
                elObj.css('border-bottom', '1px #929292 dotted');
                elObj.css('text-align', 'left');
                elObj.css('display', 'block');
                elObj.css('cursor', 'pointer');
            }
            if (element.toLowerCase() == 'a') {
                if (elObj.css('width') != '')
                    elObj.css('width', CTXT_M_WIDTH);
                if (elObj.css('height') != '')
                    elObj.css('height', CTXT_M_LINE_HEIGHT + 'px');

                elObj.hover(
                    function() { $(this).css('color', '#929292'); },
                    function() { $(this).css('color', 'white'); }
                );
            }
            if (element.toLowerCase() == 'div:context-menu') {
                if (elObj.css('width') != '')
                    elObj.css('width', CTXT_M_WIDTH);
                if (elObj.css('height') != '')
                    elObj.css('height', CTXT_M_HEIGHT);

                elObj.css('position', 'absolute');
                elObj.css('opacity', 0.8);
                elObj.css('border', '1px #929292 solid');
                elObj.hide();
            }
            if (element.toLowerCase() == 'div:saveable') {
                elObj.hide();
            }
        return;
    }
    function jv_dpgfrontend_editmode_setup_css() {
        // context menu
            $('.dpgem-imgbtn-menu-context').each(function() {
                $(this).find('p').each(function() {
                    _jv_dpgfrontend_editmode_remove_styles($(this), $(this).get(0).tagName);
                });
                $(this).find('a').each(function() {
                    _jv_dpgfrontend_editmode_remove_styles($(this), $(this).get(0).tagName);
                });
                _jv_dpgfrontend_editmode_remove_styles($(this), 'div:context-menu');
            });

        // other components
            $('.dpgem-simple-text-menu').each(function() {
                $(this).parent().hide();
            });
            $('.dpgem-imgbtn-delete').each(
                function(i) {
                    $(this).css('float', 'left');
                    $(this).css('cursor', 'pointer');
                }
            );
    }

    /**
     * jv_dpgfrontend_editmode_append_layers()
     *
     * This function appends all layer that can be opened
     * dynmically and are positioned via "top" and "left" attributes
     * of the layer. This is due to the problem that sometimes
     * the left and top values are counted relatively even if
     * the layer is positioned absolutely.
     *
     * Finally, this function sets the z-index of all important layer
     * to a maximal value compared to all other present dom elements on the page.
     *
     * @access private
     * @return void
     **/
    function jv_dpgfrontend_editmode_append_layers() {
        // deduce maximal z-index to set
        var maxZIndex = 0;
        $('body').find('*').each(function(){
            maxZIndex = Math.max(
                maxZIndex,
                isNaN(parseFloat($(this).css('z-index')))? 0: parseFloat($(this).css('z-index'))
            );
        });

        // increase z-index
        maxZIndex += 10;

        // this : toolbar
        $('#dynamic-container').css('z-index', maxZIndex);
        $('#loadingBar').css('z-index', maxZIndex + 1);
        $('#dpgem-toolbar').css('z-index', maxZIndex + 2);

        // increase z-index
        maxZIndex += 10;

        // em-layer.tpl : multifunction layer
        $('.dpgem-multifunction-layer').each(
            function(i) {
                // set z-index to maximum
                $(this).css('z-index', maxZIndex);

                // re-append layer
                var innerHTML = $(this).html();
                var attributes = $(this).getAttributes();
                var tagName = $(this).get(0).tagName;
                $(this).remove();
                if (jQuery.trim($(this).text()) != '') {
                    // check emptyness due to IE9 handling
                    $('body').append(
                        '<' + tagName + attributes + '>' + innerHTML + '</' + tagName + '>'
                    );
                }
            }
        );

        // menu-text.tpl : context menus
        $('.dpgem-imgbtn-menu-context').each(
            function(i) {
                // set z-index to maximum
                $(this).css('z-index', maxZIndex);

                // re-append layer
                var innerHTML = $(this).html();
                var attributes = $(this).getAttributes();
                var tagName = $(this).get(0).tagName;
                $(this).remove();
                if (jQuery.trim($(this).text()) != '') {
                    // check emptyness due to IE9 handling
                    $('body').append(
                        '<' + tagName + attributes + '>' + innerHTML + '</' + tagName + '>'
                    );
                }
            }
        );
    }

    /**
     * jv_dpgfrontend_editmode_setup_object_embeddings()
     *
     * Add the "wmode" parameter with value "opaque" to every <object>
     * tag within the current html such that these object can be overlayed
     * by html elements(i.e. the edit mode toolbar).
     *
     * @access private
     * @return void
     **/
    function _jv_remove_script_tags(data) {
        if (data)
            data = data.replace(/<script[^>]*>[^<]*<\/script>/ig, '');
        return data;
    }
    function jv_dpgfrontend_editmode_setup_object_embeddings() {
        var is_msie = /msie/.test(navigator.userAgent.toLowerCase());

        // if current browser is not IE then add the <param> tag
        // and the attribute "wmode" to <embed> for each <object> in DOM
        if (!is_msie) {
            // unfortunately, in IE this does not work
            $('object').each(function() {
                var wmode = false;
                $(this).children('param').each(function() {
                    if (wmode)
                        return;
                    if ($(this).attr('name').toLowerCase() == 'wmode') {
                        $(this).attr('value', 'opaque');
                        wmode = true;
                    }
                });
                if (!wmode)
                    $(this).append('<param name="wmode" value="opaque" />');
                $(this).children('embed').each(function() {
                    $(this).attr('wmode', 'opaque');
                });
            });
        }

        // re-insert the <object> tag into the DOM such that the new "wmode"
        // could take effekt (simply changing the attribute as above does
        // not suffice)
        $('object').each(function(i) {
            var p = $(this).parent();
            var c = $(this).html();
            var a = $(this).getAttributes();
            var h = _jv_remove_script_tags(p.html());

            if (h && p) {
                if (is_msie) {
                    // IE hack: in IE setting the parameters as above does not work so that
                    // we try the workaround below
                    if (/name="wmode"[\s\n]*value="\w+"/ig.test(h) || /value="\w+"[\s\n]*name="wmode"/ig.test()) {
                        h = h.replace(/name="wmode"[\s\n]*value="\w+"/ig, 'name="wmode" value="opaque"');
                        h = h.replace(/value="\w+"[\s\n]*name="wmode"/ig, 'name="wmode" value="opaque"');
                    } else
                        h += '<param name="WMode" value="opaque" />';
                }
                p.children().remove();
                p.html(h);
            }
        });
    }

    /* -------------------------------------------------------------------------
     *
     *  global event handlers
     *
     * -------------------------------------------------------------------------
     */
     $(window).scroll(function() {
        $('.mceExternalToolbar').each(function() {
            var dynamicTinyMCE = ($(this).attr('id').search(/T(\w+)_EID\w+_ID(\w+)_external/) != -1);
            if (dynamicTinyMCE)
                $(this).hide();
        });
     });

    /* -------------------------------------------------------------------------
     *
     */
});


/*
 * jQuery Extension
 *
 * @Description:
 * Add function "getAttributes()" to jQuery objects which
 * returns a string containing all attributes and values, e.g. given html code
 *
 *   <a id="foo" href="./foo.php" class="web-link">Foo</a>
 *
 * then $('#foo').getAttributes() returns the string
 *
 *   id="foo" href="./foo.php" class="web-link"
 *
 */
(function($) {
    $.fn.getAttributes = function() {
        var attributes = '';

        if(!this.length)
            return this;

        $.each(this[0].attributes, function(index, attr) {
            attributes += ' ' + attr.name + '="' + attr.value + '"';
        });

        return attributes;
    }
})(jQuery);